nltk.test.unit.test_seekable_unicode_stream_reader module
=========================================================

.. automodule:: nltk.test.unit.test_seekable_unicode_stream_reader
    :members:
    :undoc-members:
    :show-inheritance:
